www-thermferm/profiles.php

changeset 191
c74bbc24a1c8
parent 141
f19a52a25ff5
child 192
5d013b4a9138
--- a/www-thermferm/profiles.php	Thu Aug 07 16:44:53 2014 +0200
+++ b/www-thermferm/profiles.php	Thu Aug 07 19:38:30 2014 +0200
@@ -31,7 +31,7 @@
     load('index.php');
 }
 
-socket_write($sock, "LIST PROFILES", 4096);
+socket_write($sock, "PROFILE LIST", 4096);
 $answer = "";
 while (1) {
     $line = socket_read($sock, 4096);
@@ -41,7 +41,7 @@
 }
 socket_close($sock);
 /*
  * $arr contains the complete reply of he LIST PROFILES command.
  */
 $arr = explode("\r\n", $answer);
 
@@ -98,7 +98,7 @@
 	load('profiles.php');
     }
 
-    socket_write($sock, "PROFILES GETS ".$UUID, 4096);
+    socket_write($sock, "PROFILE GETS ".$UUID, 4096);
     $answer = "";
     while (1) {
 	$line = socket_read($sock, 4096);
@@ -41,7 +41,7 @@
 socket_close($sock);
 /*
- * $arr contains the complete reply of he LIST PROFILES command.
+ * $arr contains the complete reply of he PROFILE LIST command.
  */
 $arr = explode("\r\n", $answer);

mercurial